==> moodle_1.3.1.orig.tar.gz: moodle/lang/th/workshop.php <==
<?PHP // $Id: workshop.php,v 1.3 2004/03/19 06:30:20 moodler Exp $ 
      // workshop.php - created with Moodle 1.2 Beta (2004022400)


$string['absent'] = 'Ҵ';
$string['accumulative'] = '';
$string['action'] = 'ͧ÷..';
$string['addacomment'] = 'ʹ';
$string['afterdeadline'] = 'ѧ˹: $a';
$string['agreetothisassessment'] = '繴¡ѺûԹ';
$string['allgradeshaveamaximumof'] = 'اشͧءô: $a';
$string['allowresubmit'] = '͹حҵ觫';
$string['alreadyinphase'] = '㹢鹵͹ $a';
$string['amendassessmentelements'] = 'ͧСͺûԹ';
$string['amendtitle'] = 'Ǣ';
$string['analysisofassessments'] = 'šûԹ';
$string['assess'] = 'Թ';
$string['assessedon'] = '١Թ $a';
$string['assessment'] = 'Թ';
$string['assessmentby'] = 'Թ $a';
$string['assessmentdropped'] = 'СûԹ';
$string['assessmentgrade'] = 'дѺûԹ: $a';
$string['assessmentnotyetagreed'] = 'ûԹѧ繴';
$string['assessmentofresubmission'] = 'ûԹҹѺõǨҹ ẺʴṹФԴѺ  ѡ¹ӡ¡ԡṹѧͷӡ䢧ҹ';
$string['assessmentofthissubmission'] = 'šûԹͧҹ';
$string['assessments'] = 'ûԹ';
$string['assessmentsareok'] = 'šûԹ :: º´';
$string['assessmentsby'] = 'Թ $a';
$string['assessmentsdone'] = 'Թ';
$string['assessmentsexcluded'] = 'ӹǹͧûԹ $a';
$string['assessmentsmustbeagreed'] = 'šûԹͧ繾ͧѹ';
$string['assessmentwasagreedon'] = ' $a';
$string['assessor'] = 'Թ';
$string['assessthissubmission'] = 'ѺšûԹ';
$string['assignmentnotinthecorrectphase'] = 'ͺ¡ԨԴ鹵͹';
$string['authorofsubmission'] = '';
$string['averageerror'] = 'ͼԴҴ';
$string['awaitinggradingbyteacher'] = 'ô $a';
$string['beforedeadline'] = '͹˹: $a';
$string['calculationoffinalgrades'] = 'ôش';
$string['closeassignment'] = 'ԴԨ';
$string['comment'] = 'ʹ';
$string['commentby'] = 'ʹ';
$string['confirmdeletionofthisitem'] = '׹ѹź $a';
$string['correct'] = '١ͧ';
$string['criterion'] = 'ࡳ';
$string['deadline'] = '˹';
$string['deadlineis'] = '˹觤 $a';
$string['delete'] = 'ź';
$string['deleting'] = 'ѧź';
$string['description'] = '´';
$string['detailsofassessment'] = '´ûԹ';
$string['disagreewiththisassessment'] = '繴¡ѺšûԹ';
$string['displayoffinalgrades'] = 'ʴôش';
$string['dontshowgrades'] = 'ͧʴô';
$string['edit'] = '';
$string['editacomment'] = '䢢ʹ';
$string['editingassessmentelements'] = 'ͧСͺûԹ';
$string['element'] = 'ͧСͺ';
$string['elementweight'] = 'ҹ˹ѡͧСͺ';
$string['errorbanded'] = 'ҤԴҴ';
$string['errortable'] = 'ҧԴҴ';
$string['excellent'] = 'ҡ';
$string['excludingdroppedassessments'] = 'ûԹ١Ѵ͡';
$string['expectederror'] = 'ҼԴҴҨ: $a';
$string['feedbackgoeshere'] = 'ʹ';
$string['generalcomment'] = 'ʹз';
$string['good'] = '';
$string['grade'] = 'ô';
$string['gradeassessment'] = 'ûԹô';
$string['graded'] = 'ô';
$string['gradedbyteacher'] = 'ô $a';
$string['gradeforassessments'] = 'дѺûԹ';
$string['gradeforbias'] = 'дѺ§';
$string['gradeforreliability'] = 'дѺ';
$string['gradeforstudentsassessment'] = 'дѺûԹ¼¹';
$string['gradeforsubmission'] = 'ôͧ觧ҹ';
$string['gradeofsubmission'] = 'ôͧ͹ѵ: $a';
$string['gradetable'] = 'ҧô';
$string['gradingstrategy'] = 'Ըաô';
$string['hidegradesbeforeagreement'] = 'ʴô͹繴';
$string['hidenamesfromstudents'] = 'ʴͨҡ $a';
$string['includeteachersgrade'] = 'ôҡҨ͹';
$string['incorrect'] = '١ͧ';
$string['iteration'] = 'Ǩҹ   $a  ';
$string['leaguetable'] = 'ҧѴӴѺҹ';
$string['listassessments'] = '¡áûԹ';
$string['listofallsubmissions'] = '¡ü͹ѵ';
$string['liststudentsassessments'] = '¡áûԹҢͧѡ¹ ';
$string['loadingforteacherassessments'] = 'Iteration $a completed';
$string['mail1'] = 'ҹͧس \'$a\'  ѺûԹ';
$string['mail10'] = 'سöԹҹس졪ͻ';
$string['mail2'] = 'ФṹöҡҹҤԺԵ \'$a\'';
$string['mail3'] = 'سöѹ㹧ҹҤԺѵ';
$string['mail4'] = '繷յͧҹ \'$a\' ';
$string['mail5'] = 'öҡҹҤԺѵ \'$a\'';
$string['mail6'] = 'ûԹŧҹ \'$a\'  ѺԨó';
$string['mail7'] = '繢ͧ  $a   öҡҹҤԺѵ';
$string['mail8'] = 'ŧҹ $a 繧ҹѺ';
$string['mail9'] = 'سһԹѹ㹧ҹҤԺѵ';
$string['managingassignment'] = 'èѴáԨ';
$string['maximumsize'] = 'Ҵ٧ش';
$string['modulename'] = '';
$string['modulenameplural'] = '';
$string['movingtophase'] = '¢ $a';
$string['namesnotshowntostudents'] = '١ʴ $a';
$string['newassessments'] = 'ҹ';
$string['newgradings'] = 'ṹ';
$string['newsubmissions'] = 'ҹ';
$string['noassessments'] = 'աûԹ';
$string['noassessmentsdone'] = 'ӡԨ';
$string['nosubmission'] = '觧ҹ';
$string['nosubmissionsavailableforassessment'] = 'ա͹ѵѺûԹ';
$string['notavailable'] = '辺';
$string['noteonassessmentelements'] = '˵ ôѺӹǹͧСͺûԹ <BR>
èѴôж١ͧ ͹ͧԹǹСͺҹ <BR>
͹ӡͺ¡Ԩ¹ 
سö <BR>
ä顷á˹Ԩ㹤
';
$string['notgraded'] = 'ô';
$string['notitlegiven'] = 'ժͧ';
$string['numberofassessmentelements'] = 'ӹǹʹ ͧСͺûԹ  ࡳ';
$string['numberofassessments'] = 'ӹǹûԹ';
$string['numberofassessmentschanged'] = 'ӹǹûԹ١¹: $a';
$string['numberofassessmentsofstudentsubmissions'] = 'ӹǹûԹҡ¹';
$string['numberofassessmentsofteachersexamples'] = 'ӹǹҧûԹҡҨ';
$string['numberofentries'] = 'ӹǹ';
$string['numberofnegativeresponses'] = 'ӹǹõͺѺ㹷ҧź';
$string['numberofsubmissions'] = 'ӹǹ: $a';
$string['on'] = ' $a';
$string['openassignment'] = 'Ԩ';
$string['optionaladjustment'] = 'ҧ͡ѺûѺ';
$string['optionforpeergrade'] = 'ҧ͡ѺôǢͧ';
$string['optionsusedinanalysis'] = 'ҧ㹡';
$string['overallgrade'] = 'ô';
$string['overallocation'] = 'ҡԹҷ';
$string['overallpeergrade'] = 'ҾôǢͧ: $a';
$string['overallteachergrade'] = 'ҾôҡҨ: $a';
$string['ownwork'] = 'Ңͧҹ';
$string['percentageofassessments'] = '繵ͧûԹж١Ѵ͡';
$string['phase'] = '鹵͹';
$string['phase1'] = '˹Ԩ';
$string['phase1short'] = '˹';
$string['phase2'] = '$a ͹ѵСûԹ';
$string['phase2short'] = '觧ҹ';
$string['phase3'] = 'šäӹǳôش';
$string['phase3short'] = 'ͧ';
$string['phase4'] = 'ʴôش';
$string['phase4short'] = 'ûԹ';
$string['phase5'] = 'ӹǹô';
$string['phase5short'] = 'äӹǹ';
$string['phase6'] = 'ʴôش';
$string['phase6short'] = 'ʴô';
$string['pleaseassesstheseexamplesfromtheteacher'] = 'ôԹҧҹҨҡ $a';
$string['pleaseassessthesestudentsubmissions'] = 'ôԹ $a ';
$string['pleaseassessyoursubmissions'] = 'سһԹҹ';
$string['poor'] = '';
$string['present'] = '';
$string['reasonforadjustment'] = '˵ؼŢͧûѺ';
$string['reassess'] = 'Թա';
$string['repeatanalysis'] = '';
$string['reply'] = 'ͺѺ';
$string['returnto'] = 'Ѻ价';
$string['returntosubmissionpage'] = 'Ѻ价˹ҡ͹ѵ';
$string['rubric'] = '˵';
$string['savedok'] = 'úѹ֡º';
$string['saveleaguetableoptions'] = 'ѹ֡ͧ͡ҧ';
$string['savemyassessment'] = 'ѹ֡ûԹͧѹ';
$string['savemycomment'] = 'ѹ֡âʹТͧѹ';
$string['savemygrading'] = 'ѹ֡ôͧѹ';
$string['saveoverallocation'] = 'ѹ֡èѴ÷Թ';
$string['scale10'] = ' 10 ṹ';
$string['scale100'] = ' 100 ṹ';
$string['scale20'] = ' 20 ṹ';
$string['scalecorrect'] = ' 2 дѺ ١/Դ';
$string['scaleexcellent4'] = ' 4 дѺ ҡ/ͧѺا';
$string['scaleexcellent5'] = ' 5 дѺ ҡ/ͧѺا';
$string['scaleexcellent7'] = ' 7 дѺ ҡ/ͧѺا';
$string['scalegood3'] = ' 3 дѺ /ûѺا';
$string['scalepresent'] = ' 2 дѺ /Ҵ';
$string['scaleyes'] = ' 2 дѺ /';
$string['select'] = '͡';
$string['selfassessment'] = 'ûԹͧ';
$string['setoverallocation'] = '駤ҡèѴ÷Թ';
$string['showgrades'] = 'ʴô';
$string['specimenassessmentform'] = 'ٻẺûԹҵҧ';
$string['standarddeviation'] = '§ູͧͧСͺ $a:';
$string['standarddeviationnote'] = 'ͧСͺҡѺ§ູҡѺٹͤ§硹¡öкԴ͹.<br /> ͧСͺ١Ѵ͡ҡûԹ';
$string['studentassessments'] = 'ûԹ $a  ';
$string['studentgrades'] = 'ṹͧѡ¹ $a  ';
$string['studentsubmissions'] = 'ҹ $a  ';
$string['studentsubmissionsforassessment'] = 'ҹͧѡ¹ѺûԹ $a ';
$string['submission'] = 'ҹ';
$string['submissions'] = 'ҹ';
$string['submissionsnolongerallowed'] = '͹حҵ觧ҹ';
$string['submissionsused'] = '$a 駢ͧ觧ҹ١㹵ҧ';
$string['submitassignment'] = 'ͺҹ';
$string['submitassignmentusingform'] = '觧ҹͧس';
$string['submitexampleassignment'] = 'ͺҧҹ';
$string['submitrevisedassignment'] = '觧ҹ';
$string['submitted'] = '';
$string['submittedby'] = '';
$string['suggestedgrade'] = 'ṹ';
$string['teacherassessments'] = '$a ûԹ';
$string['teacherscomment'] = 'ʹШҡҨ';
$string['teachersgrade'] = 'ôҡҨ';
$string['teachersubmissionsforassessment'] = '$a Ҩ͹ѵԡûԹ';
$string['thegradeis'] = 'дѺṹ $a';
$string['thereisfeedbackfromtheteacher'] = 'դ繨ҡ $a ';
$string['theseasessmentsaregradedbytheteacher'] = 'ûԹô $a';
$string['timeassessed'] = 'һԹ';
$string['title'] = '¡';
$string['typeofscale'] = 'ͧ';
$string['ungradedassessmentsofstudentsubmissions'] = '$a ûԹҢͧԵдѺṹ';
$string['ungradedassessmentsofteachersubmissions'] = '$a ûԹҢͧҨдѺṹ';
$string['verypoor'] = 'ҡ';
$string['view'] = 'ʴ';
$string['viewassessmentofteacher'] = 'ʴҡûԹͧ $a';
$string['viewotherassessments'] = 'ʴҡûԹ ';
$string['warningonamendingelements'] = '͹: ûԹѺ͹ѵ <BR> ¹ŢͧͧСͺ, ͤҹ˹ѡ ';
$string['weight'] = 'ҹ˹ѡ';
$string['weightederrorcount'] = 'ӹǹҹ˹ѡԴҴ: $a';
$string['weightforbias'] = 'ҹ˹ѡä§';
$string['weightforgradingofassessments'] = 'ҹ˹ѡѺдѺṹûԹ';
$string['weightforpeerassessments'] = 'ҹ˹ѡѺԹ';
$string['weightforreliability'] = 'ҹ˹ѡͶ';
$string['weights'] = 'ҹ˹ѡ';
$string['weightsusedforfinalgrade'] = 'ҹ˹ѡѺдѺṹش';
$string['weightsusedforsubmissions'] = 'ҹ˹ѡѺùѵ';
$string['workshopagreedassessments'] = 'ûԹҤԺѵԷʹͧ';
$string['workshopassessments'] = 'ûԹҤԺѵ';
$string['workshopcomments'] = 'ԴҤԺѵ';
$string['workshopfeedback'] = 'ʹҤԺѵ';
$string['workshopsubmissions'] = '觧ҹҤԺѵ';
$string['yourassessments'] = 'ûԹͧس';
$string['yourassessmentsofexamplesfromtheteacher'] = 'ûԹͧسҡҧ$a';
$string['yourfeedbackgoeshere'] = 'ʴԴ繷';

?>

==> moodle_1.4.3.orig.tar.gz: moodle/lang/th/workshop.php <==
<?PHP // $Id$ 
      // workshop.php - created with Moodle 1.4 development (2004060400)


$string['absent'] = 'Ҵ';
$string['accumulative'] = '';
$string['action'] = 'ͧ÷..';
$string['addacomment'] = 'ʹ';
$string['afterdeadline'] = 'ѧ˹: $a';
$string['agreetothisassessment'] = '繴¡ѺûԹ';
$string['allgradeshaveamaximumof'] = 'اشͧءô: $a';
$string['allowresubmit'] = '͹حҵ觫';
$string['alreadyinphase'] = '㹢鹵͹ $a';
$string['amendassessmentelements'] = 'ͧСͺûԹ';
$string['amendtitle'] = 'Ǣ';
$string['analysisofassessments'] = 'šûԹ';
$string['assess'] = 'Թ';
$string['assessedon'] = '١Թ $a';
$string['assessment'] = 'Թ';
$string['assessmentby'] = 'Թ $a';
$string['assessmentdropped'] = 'СûԹ';
$string['assessmentgrade'] = 'дѺûԹ: $a';
$string['assessmentnotyetagreed'] = 'ѧբػšûԹ';
$string['assessmentofresubmission'] = 'ûԹҹѺõǨҹ ẺʴṹФԴѺ  ѡ¹ӡ¡ԡṹѧͷӡ䢧ҹ';
$string['assessmentofthissubmission'] = 'šûԹͧҹ';
$string['assessments'] = 'ûԹ';
$string['assessmentsareok'] = 'šûԹ :: º´';
$string['assessmentsby'] = 'Թ $a';
$string['assessmentsdone'] = 'Թ';
$string['assessmentsexcluded'] = 'ӹǹͧûԹ $a';
$string['assessmentsmustbeagreed'] = 'šûԹͧ͡ѹ';
$string['assessmentwasagreedon'] = 'šûԹ͡ѹ $a';
$string['assessor'] = 'Թ';
$string['assessthissubmission'] = 'ѺšûԹ';
$string['assignmentnotinthecorrectphase'] = 'ͺ¡ԨԴ鹵͹';
$string['authorofsubmission'] = '';
$string['averageerror'] = 'ͼԴҴ';
$string['awaitinggradingbyteacher'] = '͡ṹ $a';
$string['beforedeadline'] = '͹˹: $a';
$string['calculationoffinalgrades'] = 'ṹش';
$string['closeassignment'] = 'ԴԨ';
$string['comment'] = 'ʹ';
$string['commentby'] = 'ʹ';
$string['confirmdeletionofthisitem'] = '׹ѹź $a';
$string['correct'] = '١ͧ';
$string['criterion'] = 'ࡳ';
$string['deadline'] = '˹';
$string['deadlineis'] = '˹觤 $a';
$string['delete'] = 'ź';
$string['deleting'] = 'ѧź';
$string['description'] = '´';
$string['detailsofassessment'] = '´ûԹ';
$string['disagreewiththisassessment'] = '繴¡ѺšûԹ';
$string['displayoffinalgrades'] = 'ʴṹ';
$string['dontshowgrades'] = 'ͧʴṹ';
$string['edit'] = '';
$string['editacomment'] = '䢢ʹ';
$string['editingassessmentelements'] = 'ͧСͺûԹ';
$string['element'] = 'ͧСͺ';
$string['elementweight'] = 'ҹ˹ѡͧСͺ';
$string['errorbanded'] = 'ǧҴ͹';
$string['errortable'] = 'ҧҴ͹';
$string['excellent'] = 'ҡ';
$string['excludingdroppedassessments'] = 'ûԹ١Ѵ͡';
$string['expectederror'] = 'ԴդҴ͹: $a';
$string['feedbackgoeshere'] = 'ʹ';
$string['generalcomment'] = 'ʹз';
$string['good'] = '';
$string['grade'] = 'ṹ';
$string['gradeassessment'] = 'ûԹô';
$string['graded'] = 'ṹ';
$string['gradedbyteacher'] = 'ṹ $a';
$string['gradeforassessments'] = 'ṹûԹ';
$string['gradeforbias'] = 'ṹ§';
$string['gradeforreliability'] = 'ṹ';
$string['gradeforstudentsassessment'] = 'ṹûԹͧ';
$string['gradeforsubmission'] = 'ṹ觧ҹ';
$string['gradeofsubmission'] = 'ṹ觧ҹ: $a';
$string['gradetable'] = 'ҧṹ';
$string['gradingstrategy'] = 'Ըաṹ';
$string['hidegradesbeforeagreement'] = '͹ṹ騹Ҩ繾ͧ';
$string['hidenamesfromstudents'] = '͹ $a ';
$string['includeteachersgrade'] = 'ṹҡҨ͹';
$string['incorrect'] = '١ͧ';
$string['iteration'] = 'Ǩҹ   $a  ';
$string['leaguetable'] = 'ҧѴӴѺҹ';
$string['listassessments'] = '¡áûԹ';
$string['listofallsubmissions'] = '¡çҹ';
$string['liststudentsassessments'] = '¡áûԹͧ';
$string['loadingforteacherassessments'] = 'ѧŴûԹ $a ';
$string['mail1'] = 'ҹͧس \'$a\'  ѺûԹ';
$string['mail10'] = 'سöԹҹ㹧ҹҤԺѵ';
$string['mail2'] = 'ФṹöҡҹҤԺԵ \'$a\'';
$string['mail3'] = 'سöѹ㹧ҹҤԺѵ';
$string['mail4'] = '繷յͧҹ \'$a\' ';
$string['mail5'] = 'öҡҹҤԺѵ \'$a\'';
$string['mail6'] = 'ûԹŧҹ \'$a\'  ѺԨó';
$string['mail7'] = '繢ͧ  $a   öҡҹҤԺѵ';
$string['mail8'] = 'ŧҹ $a 繧ҹѺ';
$string['mail9'] = 'سһԹ㹧ҹҤԺѵ';
$string['managingassignment'] = 'èѴáԨ';
$string['maximumsize'] = 'Ҵ٧ش';
$string['modulename'] = 'ͧԺѵԡ';
$string['modulenameplural'] = 'ͧԺѵԡ';
$string['movingtophase'] = '¢ $a';
$string['namesnotshowntostudents'] = '١ʴ $a';
$string['newassessments'] = 'ҹ';
$string['newgradings'] = 'ṹ';
$string['newsubmissions'] = 'ҹ';
$string['noassessments'] = 'աûԹ';
$string['noassessmentsdone'] = 'ӡԨ';
$string['nosubmission'] = '觧ҹ';
$string['nosubmissionsavailableforassessment'] = 'ա͹ѵѺûԹ';
$string['notavailable'] = '辺';
$string['noteonassessmentelements'] = '˵ ṹǹ  ṹͧСͺûԹ <br />
ټ͹繵ͧкء͹Ҩṹҹ㴺ҧǨ֧觧ҹѡ¹';
$string['notgraded'] = 'աṹ';
$string['notitlegiven'] = 'ժͧ';
$string['numberofassessmentelements'] = 'ӹǹʹ,ͧСͺûԹ,дѺṹ,ࡳṹ, ٺԡ';
$string['numberofassessments'] = 'ӹǹûԹ';
$string['numberofassessmentschanged'] = 'ӹǹûԹ١¹: $a';
$string['numberofassessmentsofstudentsubmissions'] = 'ӹǹҹöӡûԹ';
$string['numberofassessmentsofteachersexamples'] = 'ӹǹҧûԹҡҨ';
$string['numberofentries'] = 'ӹǹ';
$string['numberofnegativeresponses'] = 'ӹǹõͺѺ㹷ҧź';
$string['numberofsubmissions'] = 'ӹǹ: $a';
$string['on'] = ' $a';
$string['openassignment'] = 'Ԩ';
$string['optionaladjustment'] = 'Ѻṹ';
$string['optionforpeergrade'] = 'ṹԹ';
$string['optionsusedinanalysis'] = 'Ըշ㹡';
$string['overallgrade'] = 'ṹ';
$string['overallocation'] = 'Over Allocation';
$string['overallpeergrade'] = 'ṹ蹻Թ: $a';
$string['overallteachergrade'] = 'ṹҨԹ: $a';
$string['ownwork'] = 'Ңͧҹ';
$string['percentageofassessments'] = '繵ͧûԹж١Ѵ͡';
$string['phase'] = '鹵͹';
$string['phase1'] = '駤ҡúҹ';
$string['phase1short'] = '駤';
$string['phase2'] = '$a 觧ҹ';
$string['phase2short'] = '觧ҹ';
$string['phase3'] = '$a 觧ҹлԹ';
$string['phase3short'] = 'ͧ';
$string['phase4'] = ' $a Թ';
$string['phase4short'] = 'ûԹ';
$string['phase5'] = 'ӹǳṹش';
$string['phase5short'] = 'ӹǳṹ';
$string['phase6'] = 'ʴṹش';
$string['phase6short'] = 'ʴṹ';
$string['pleaseassesstheseexamplesfromtheteacher'] = 'ôԹҧҹ ҡ $a';
$string['pleaseassessthesestudentsubmissions'] = 'ôԹ $a ';
$string['pleaseassessyoursubmissions'] = 'سһԹҹ';
$string['poor'] = 'ͧѺا';
$string['present'] = '';
$string['reasonforadjustment'] = '˵ؼŢͧûѺṹ';
$string['reassess'] = 'Թա';
$string['repeatanalysis'] = '';
$string['reply'] = 'ͺѺ';
$string['returnto'] = 'Ѻ价';
$string['returntosubmissionpage'] = 'Ѻ价˹ҡ͹ѵ';
$string['rubric'] = 'Rubric';
$string['savedok'] = 'úѹ֡º';
$string['saveleaguetableoptions'] = 'ѹ֡ҧѴӴѺ';
$string['savemyassessment'] = 'ѹ֡ûԹͧѹ';
$string['savemycomment'] = 'ѹ֡âʹТͧѹ';
$string['savemygrading'] = 'ѹ֡ôͧѹ';
$string['saveoverallocation'] = 'ѹ֡дѺ Over Allocation';
$string['scale10'] = 'ҡ 10 ṹ';
$string['scale100'] = 'ҡ 100 ṹ';
$string['scale20'] = 'ҡ 20 ṹ';
$string['scalecorrect'] = ' 2 дѺ ١/Դ';
$string['scaleexcellent4'] = ' 4 дѺ ҡ/ͧѺا';
$string['scaleexcellent5'] = ' 5 дѺ ҡ/ͧѺا';
$string['scaleexcellent7'] = ' 7 дѺ ҡ/ͧѺا';
$string['scalegood3'] = ' 3 дѺ /ûѺا';
$string['scalepresent'] = ' 2 дѺ /Ҵ';
$string['scaleyes'] = ' 2 дѺ /';
$string['select'] = '͡';
$string['selfassessment'] = 'ûԹͧ';
$string['setoverallocation'] = '駤дѺ Over Allocation';
$string['showgrades'] = 'ʴṹ';
$string['specimenassessmentform'] = 'ٻẺҧûԹ';
$string['standarddeviation'] = '§ູͧͧСͺ $a:';
$string['standarddeviationnote'] = 'ͧСͺҡѺ§ູҡѺٹͤ§硹¡öкԴ͹.<br /> ͧСͺ١Ѵ͡ҡûԹ';
$string['studentassessments'] = 'ûԹͧ$a';
$string['studentgrades'] = 'ṹͧ$a';
$string['studentsubmissions'] = 'ҹͧ$a ';
$string['studentsubmissionsforassessment'] = 'ҹͧѡ¹ѺûԹ $a ';
$string['submission'] = 'ҹ';
$string['submissions'] = 'ҹ';
$string['submissionsnolongerallowed'] = '͹حҵ觧ҹ';
$string['submissionsused'] = '$a 駢ͧ觧ҹ١㹵ҧ';
$string['submitassignment'] = '觧ҹ';
$string['submitassignmentusingform'] = '觧ҹͧس';
$string['submitexampleassignment'] = 'ͺҧҹ';
$string['submitrevisedassignment'] = '觧ҹ';
$string['submitted'] = '';
$string['submittedby'] = '';
$string['suggestedgrade'] = 'ṹ';
$string['teacherassessments'] = '$a ûԹ';
$string['teacherscomment'] = 'ʹШҡҨ';
$string['teachersgrade'] = 'ṹҡҨ';
$string['teachersubmissionsforassessment'] = '$a Ҩ͹ѵԡûԹ';
$string['thegradeis'] = 'дѺṹ $a';
$string['thereisfeedbackfromtheteacher'] = 'դ繨ҡ $a ';
$string['theseasessmentsaregradedbytheteacher'] = 'ṹûԹ $a';
$string['timeassessed'] = 'һԹ';
$string['title'] = 'Ǣ';
$string['typeofscale'] = 'ͧ';
$string['ungradedassessmentsofstudentsubmissions'] = 'էҹѧṹҡѡ¹  $a ';
$string['ungradedassessmentsofteachersubmissions'] = 'էҹѧѺûԹҡҨ $a ';
$string['verypoor'] = 'ҡ';
$string['view'] = 'ʴ';
$string['viewassessmentofteacher'] = 'ʴҡûԹͧ $a';
$string['viewotherassessments'] = 'ʴҡûԹ ';
$string['warningonamendingelements'] = '͹: ûԹѺ͹ѵ <br /> ¹ŢͧͧСͺ, ͤҹ˹ѡ ';
$string['weight'] = 'ҹ˹ѡ';
$string['weightederrorcount'] = 'ӹǹҹ˹ѡԴҴ: $a';
$string['weightforbias'] = 'ҹ˹ѡä§';
$string['weightforgradingofassessments'] = 'ҹ˹ѡѺдѺṹûԹ';
$string['weightforpeerassessments'] = 'ҹ˹ѡѺԹ';
$string['weightforreliability'] = 'ҹ˹ѡͶ';
$string['weightforteacherassessments'] = 'ҹ˹ѡѺҨԹ';
$string['weights'] = 'ҹ˹ѡ';
$string['weightsusedforfinalgrade'] = 'ҹ˹ѡѺдѺṹش';
$string['weightsusedforsubmissions'] = 'ҹ˹ѡѺùѵ';
$string['workshopagreedassessments'] = 'ûԹҤԺѵԷʹͧ';
$string['workshopassessments'] = 'ûԹҤԺѵ';
$string['workshopcomments'] = 'ԴҤԺѵ';
$string['workshopfeedback'] = 'ʹҤԺѵ';
$string['workshopsubmissions'] = '觧ҹҤԺѵ';
$string['yourassessments'] = 'ûԹͧس';
$string['yourassessmentsofexamplesfromtheteacher'] = 'ûԹͧسҡҧ$a';
$string['yourfeedbackgoeshere'] = 'ʴԴ繷';

?>
